@@ -70,15 +70,14 @@ setMethod("is.na", "timeSeries", function(x)
 
 # ------------------------------------------------------------------------------
 
+# something like this would be needed if is.unsorted again became an internal generic
+#if(getRversion() >= "3.3.0") {
+#    setGeneric("is.unsorted", signature = "x", useAsDefault = base::is.unsorted)
+#}
 
-if (getRversion() < "2.8.0") 
-{
-    setMethod("is.unsorted", "timeSeries", function(x, na.rm = FALSE)
-        callGeneric(x@positions, na.rm = na.rm))
-} else {
-    setMethod("is.unsorted", "timeSeries", function(x, na.rm = FALSE, strictly = FALSE)
-         callGeneric(x@positions, na.rm = na.rm, strictly = strictly))
-}
+setMethod("is.unsorted", "timeSeries",
+           function(x, na.rm = FALSE, strictly = FALSE)
+           callGeneric(x@positions, na.rm = na.rm, strictly = strictly))
 
 
 ################################################################################
